@@ -1,20 +1,5 @@
-/*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
- *                                                                                   *
- *  This program is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU General Public License                      *
- *  as published by the Free Software Foundation; either version 2                   *
- *  of the License, or (at your option) any later version.                           *
- *                                                                                   *
- *  This program is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
- *  GNU General Public License for more details.                                     *
- *                                                                                   *
- *  You should have received a copy of the GNU General Public License                *
- *  along with this program; if not, write to the Free Software                      *
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
- *************************************************************************************/
+// SPDX-FileCopyrightText: 2007 by Aleix Pol <aleixpol@kde.org>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "consolehtml.h"
 
@@ -24,15 +9,17 @@
 #include <QTemporaryFile>
 #include <QUrlQuery>
 
-#include <KStandardAction>
-#include <QMenu>
 #include <KLocalizedString>
+#include <KStandardAction>
 #include <QAction>
+#include <QMenu>
 #include <kio/copyjob.h>
 #include <kio/job.h>
 
-#include <analitza/variables.h>
 #include <analitza/expression.h>
+#include <analitza/variables.h>
+
+using namespace Qt::Literals::StringLiterals;
 
 static QUrl temporaryPath()
 {
@@ -43,10 +30,10 @@ static QUrl temporaryPath()
     return QUrl::fromLocalFile(temp.fileName());
 }
 
-static QUrl retrieve(const QUrl& remoteUrl)
+static QUrl retrieve(const QUrl &remoteUrl)
 {
     const QUrl path = temporaryPath();
-    KIO::CopyJob* job=KIO::copyAs(remoteUrl, path);
+    KIO::CopyJob *job = KIO::copyAs(remoteUrl, path);
 
     job->exec();
 
@@ -56,9 +43,14 @@ static QUrl retrieve(const QUrl& remoteUrl)
 class ConsolePage : public QWebEnginePage
 {
 public:
-    ConsolePage(ConsoleHtml* parent) : QWebEnginePage(parent), m_console(parent) {}
+    ConsolePage(ConsoleHtml *parent)
+        : QWebEnginePage(parent)
+        , m_console(parent)
+    {
+    }
 
-    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool /*isMainFrame*/) override {
+    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool /*isMainFrame*/) override
+    {
         m_console->setActualUrl(url);
 
         if (url.scheme() == QLatin1String("data"))
@@ -69,12 +61,13 @@ public:
         return false;
     }
 
-    ConsoleHtml* m_console;
+    ConsoleHtml *m_console;
 };
 
 ConsoleHtml::ConsoleHtml(QWidget *parent)
     : QWebEngineView(parent)
-    , m_actualUrl(), m_model(new ConsoleModel(this))
+    , m_actualUrl()
+    , m_model(new ConsoleModel(this))
 {
     connect(m_model.data(), &ConsoleModel::updateView, this, &ConsoleHtml::updateView);
     connect(m_model.data(), &ConsoleModel::operationSuccessful, this, &ConsoleHtml::includeOperation);
@@ -86,27 +79,28 @@ ConsoleHtml::~ConsoleHtml()
     qDeleteAll(m_options);
 }
 
-void ConsoleHtml::setActualUrl(const QUrl& url)
+void ConsoleHtml::setActualUrl(const QUrl &url)
 {
     m_actualUrl = url;
 }
 
-void ConsoleHtml::openClickedUrl(const QUrl& url)
+void ConsoleHtml::openClickedUrl(const QUrl &url)
 {
     QUrlQuery query(url);
-    QString id =query.queryItemValue(QStringLiteral("id"));
-    QString exp=query.queryItemValue(QStringLiteral("func"));
-    
-    if(id==QLatin1String("copy")) {
+    QString id = query.queryItemValue(QStringLiteral("id"));
+    QString exp = query.queryItemValue(QStringLiteral("func"));
+
+    if (id == QLatin1String("copy")) {
         Q_EMIT paste(exp);
-    } else foreach(InlineOptions* opt, m_options) {
-        if(opt->id() == id) {
-            opt->triggerOption(Analitza::Expression(exp, false));
+    } else
+        for (InlineOptions *opt : std::as_const(m_options)) {
+            if (opt->id() == id) {
+                opt->triggerOption(Analitza::Expression(exp, false));
+            }
         }
-    }
 }
 
-bool ConsoleHtml::addOperation(const Analitza::Expression& e, const QString& input)
+bool ConsoleHtml::addOperation(const Analitza::Expression &e, const QString &input)
 {
     return m_model->addOperation(e, input);
 }
@@ -121,39 +115,39 @@ void ConsoleHtml::setMode(ConsoleModel::ConsoleMode newMode)
     m_model->setMode(newMode);
 }
 
-Analitza::Analyzer* ConsoleHtml::analitza()
+Analitza::Analyzer *ConsoleHtml::analitza()
 {
     return m_model->analyzer();
 }
 
-bool ConsoleHtml::loadScript(const QUrl& path)
+bool ConsoleHtml::loadScript(const QUrl &path)
 {
     return m_model->loadScript(path.isLocalFile() ? path : retrieve(path));
 }
 
-bool ConsoleHtml::saveScript(const QUrl & path) const
+bool ConsoleHtml::saveScript(const QUrl &path) const
 {
-    const QUrl savePath=path.isLocalFile() ? path : temporaryPath();
+    const QUrl savePath = path.isLocalFile() ? path : temporaryPath();
     bool correct = m_model->saveScript(savePath);
-    if(!path.isLocalFile()) {
-        KIO::CopyJob* job=KIO::move(savePath, path);
-        correct=job->exec();
+    if (!path.isLocalFile()) {
+        KIO::CopyJob *job = KIO::move(savePath, path);
+        correct = job->exec();
     }
     return correct;
 }
 
-bool ConsoleHtml::saveLog(const QUrl & path) const
+bool ConsoleHtml::saveLog(const QUrl &path) const
 {
-    const QUrl savePath=path.isLocalFile() ? path : temporaryPath();
+    const QUrl savePath = path.isLocalFile() ? path : temporaryPath();
     bool correct = m_model->saveLog(savePath);
-    if(!path.isLocalFile()) {
-        KIO::CopyJob* job=KIO::move(savePath, path);
-        correct=job->exec();
+    if (!path.isLocalFile()) {
+        KIO::CopyJob *job = KIO::move(savePath, path);
+        correct = job->exec();
     }
     return correct;
 }
 
-void ConsoleHtml::includeOperation(const Analitza::Expression& /*e*/, const Analitza::Expression& res)
+void ConsoleHtml::includeOperation(const Analitza::Expression & /*e*/, const Analitza::Expression &res)
 {
     m_optionsString.clear();
     if (res.isCorrect()) {
@@ -162,8 +156,8 @@ void ConsoleHtml::includeOperation(const Analitza::Expression& /*e*/, const Anal
         Analitza::Expression lambdaexp = lambdifier.dependenciesToLambda();
         lambdifier.setExpression(lambdaexp);
 
-        foreach(InlineOptions* opt, m_options) {
-            if(opt->matchesExpression(lambdaexp)) {
+        for (InlineOptions *opt : std::as_const(m_options)) {
+            if (opt->matchesExpression(lambdaexp)) {
                 QUrl url(QStringLiteral("/query"));
                 QUrlQuery query(url);
                 query.addQueryItem(QStringLiteral("id"), opt->id());
@@ -174,8 +168,8 @@ void ConsoleHtml::includeOperation(const Analitza::Expression& /*e*/, const Anal
             }
         }
 
-        if(!m_optionsString.isEmpty()) {
-            m_optionsString = "<div class='options'>"+i18n("Options: %1", m_optionsString)+"</div>";
+        if (!m_optionsString.isEmpty()) {
+            m_optionsString = u"<div class='options'>"_s + i18n("Options: %1", m_optionsString) + u"</div>"_s;
         }
     }
 }
@@ -191,8 +185,8 @@ void ConsoleHtml::updateView()
     auto log = m_model->htmlLog();
     if (!log.isEmpty()) {
         const auto newEntry = log.takeLast();
-        foreach(const QString &entry, log)
-            code += "<p class='normal'>" + entry.toUtf8() + "</p>\n";
+        for (const QByteArray &entry : std::as_const(log))
+            code += "<p class='normal'>" + entry + "</p>\n";
 
         code += m_optionsString.toUtf8();
         if (newEntry.startsWith("<ul class='error'>"))
@@ -202,11 +196,11 @@ void ConsoleHtml::updateView()
     }
     code += "</body></html>";
 
-    page()->setHtml(code);
+    page()->setHtml(QString::fromUtf8(code));
 
     Q_EMIT changed();
 
-    connect(this, &QWebEngineView::loadFinished, this, [this](bool ok){
+    connect(this, &QWebEngineView::loadFinished, this, [this](bool ok) {
         if (!ok && (m_actualUrl.scheme() != QLatin1String("kalgebra"))) {
             qWarning() << "error loading page" << m_actualUrl;
         }
@@ -220,18 +214,18 @@ void ConsoleHtml::copy() const
     QApplication::clipboard()->setText(selectedText());
 }
 
-void ConsoleHtml::contextMenuEvent(QContextMenuEvent* ev)
+void ConsoleHtml::contextMenuEvent(QContextMenuEvent *ev)
 {
     QMenu popup;
-    if(hasSelection()) {
+    if (hasSelection()) {
         popup.addAction(KStandardAction::copy(this, SLOT(copy()), &popup));
-        QAction *act=new QAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("Paste \"%1\" to input", selectedText().trimmed()), &popup);
+        QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("Paste \"%1\" to input", selectedText().trimmed()), &popup);
         connect(act, SIGNAL(triggered()), SLOT(paste()));
         popup.addAction(act);
         popup.addSeparator();
     }
     popup.addAction(KStandardAction::clear(this, SLOT(clear()), &popup));
-    
+
     popup.exec(mapToGlobal(ev->pos()));
 }
 
@@ -241,12 +235,12 @@ void ConsoleHtml::clear()
     updateView();
 }
 
-void ConsoleHtml::modifyVariable(const QString& name, const Analitza::Expression& exp)
+void ConsoleHtml::modifyVariable(const QString &name, const Analitza::Expression &exp)
 {
     m_model->variables()->modify(name, exp);
 }
 
-void ConsoleHtml::removeVariable(const QString & name)
+void ConsoleHtml::removeVariable(const QString &name)
 {
     m_model->variables()->remove(name);
 }
