@@ -17,29 +17,30 @@
  *************************************************************************************/
 
 #include "kalgebra.h"
-#include "varedit.h"
+#include "askname.h"
 #include "consolehtml.h"
 #include "dictionary.h"
-#include "askname.h"
+#include "functionedit.h"
+#include "varedit.h"
 #include "variablesdelegate.h"
 #include "viewportwidget.h"
-#include "functionedit.h"
 #include <analitzagui/plotsview3d_es.h>
 
-#include <analitzagui/operatorsmodel.h>
+#include <analitza/value.h>
+#include <analitza/variables.h>
 #include <analitzagui/expressionedit.h>
-#include <analitzagui/variablesmodel.h>
+#include <analitzagui/operatorsmodel.h>
 #include <analitzagui/plotsview2d.h>
-#include <analitzaplot/plotsmodel.h>
+#include <analitzagui/variablesmodel.h>
 #include <analitzaplot/functiongraph.h>
 #include <analitzaplot/planecurve.h>
 #include <analitzaplot/plotsfactory.h>
-#include <analitza/variables.h>
-#include <analitza/value.h>
+#include <analitzaplot/plotsmodel.h>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KHelpMenu>
+#include <KLocalizedString>
 #include <KRecentFilesAction>
 #include <KStandardAction>
 #include <KToggleFullScreenAction>
@@ -57,50 +58,73 @@
 #include <QTableView>
 #include <QToolButton>
 #include <QVBoxLayout>
-#include <klocalizedstring.h>
+
+using namespace Qt::Literals::StringLiterals;
 
 class Add2DOption : public InlineOptions
 {
-    public:
-        Add2DOption(KAlgebra* c)
+public:
+    Add2DOption(KAlgebra *c)
         : m_kalgebra(c)
-        {}
-        
-        QString id() const override { return QStringLiteral("add2d"); }
-        bool matchesExpression(const Analitza::Expression& exp) const override {
-            return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim2D).canDraw();
-        }
+    {
+    }
 
-        QString caption() const override { return i18n("Plot 2D"); }
+    QString id() const override
+    {
+        return QStringLiteral("add2d");
+    }
+    bool matchesExpression(const Analitza::Expression &exp) const override
+    {
+        return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim2D).canDraw();
+    }
 
-        void triggerOption(const Analitza::Expression& exp) override { m_kalgebra->add2D(exp); }
-    
-    private:
-        KAlgebra* m_kalgebra;
+    QString caption() const override
+    {
+        return i18n("Plot 2D");
+    }
+
+    void triggerOption(const Analitza::Expression &exp) override
+    {
+        m_kalgebra->add2D(exp);
+    }
+
+private:
+    KAlgebra *m_kalgebra;
 };
 
 class Add3DOption : public InlineOptions
 {
-    public:
-        Add3DOption(KAlgebra* c)
+public:
+    Add3DOption(KAlgebra *c)
         : m_kalgebra(c)
-        {}
-        
-        QString id() const override { return QStringLiteral("add3d"); }
-        bool matchesExpression(const Analitza::Expression& exp) const override
-        {
-            return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D).canDraw();
-        }
+    {
+    }
 
-        QString caption() const override { return i18n("Plot 3D"); }
+    QString id() const override
+    {
+        return QStringLiteral("add3d");
+    }
+    bool matchesExpression(const Analitza::Expression &exp) const override
+    {
+        return Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D).canDraw();
+    }
 
-        void triggerOption(const Analitza::Expression& exp) override { m_kalgebra->add3D(exp); }
-    
-    private:
-        KAlgebra* m_kalgebra;
+    QString caption() const override
+    {
+        return i18n("Plot 3D");
+    }
+
+    void triggerOption(const Analitza::Expression &exp) override
+    {
+        m_kalgebra->add3D(exp);
+    }
+
+private:
+    KAlgebra *m_kalgebra;
 };
 
-QColor randomFunctionColor() {
+QColor randomFunctionColor()
+{
     return QColor::fromHsv(QRandomGenerator::global()->bounded(255), 255, 255);
 }
 
@@ -108,58 +132,58 @@ KAlgebra::KAlgebra(QWidget *parent)
     : QMainWindow(parent)
 {
     resize(900, 500);
-    
+
     m_tabs = new QTabWidget;
     setCentralWidget(m_tabs);
-    
+
     setStatusBar(new QStatusBar(this));
     setMenuBar(new QMenuBar(this));
-    
-    KToggleFullScreenAction* fullScreenAction = KStandardAction::fullScreen(this, SLOT(fullScreen(bool)), this, this);
-    
-    QMenu* g_menu = menuBar()->addMenu(i18n("Session"));
+
+    KToggleFullScreenAction *fullScreenAction = KStandardAction::fullScreen(this, SLOT(fullScreen(bool)), this, this);
+
+    QMenu *g_menu = menuBar()->addMenu(i18n("Session"));
     g_menu->addAction(KStandardAction::openNew(this, SLOT(newInstance()), this));
     g_menu->addAction(fullScreenAction);
     g_menu->addSeparator();
     g_menu->addAction(KStandardAction::quit(this, SLOT(close()), this));
-    
-    QToolButton* fullScreenButton = new QToolButton(this);
+
+    QToolButton *fullScreenButton = new QToolButton(this);
     fullScreenButton->setDefaultAction(fullScreenAction);
     m_tabs->setCornerWidget(fullScreenButton);
-    
+
     m_status = new QLabel(this);
     statusBar()->insertWidget(0, m_status);
     menuBar()->addAction(QStringLiteral("|"))->setEnabled(false);
-    
+
     ///////Console
     QWidget *console = new QWidget(m_tabs);
     QVBoxLayout *c_layo = new QVBoxLayout(console);
     c_results = new ConsoleHtml(console);
     c_results->setFocusPolicy(Qt::NoFocus);
     c_dock_vars = new QDockWidget(i18n("Variables"), this);
-    c_dock_vars->setFeatures(QDockWidget::DockWidgetFloatable|QDockWidget::DockWidgetMovable);
+    c_dock_vars->setFeatures(QDockWidget::DockWidgetFloatable | QDockWidget::DockWidgetMovable);
     addDockWidget(Qt::RightDockWidgetArea, c_dock_vars);
-    
-    c_varsModel=new Analitza::VariablesModel(c_results->analitza()->variables());
+
+    c_varsModel = new Analitza::VariablesModel(c_results->analitza()->variables());
     c_varsModel->setEditable(false);
-    
+
     c_variables = new QTreeView(c_dock_vars);
     c_variables->setModel(c_varsModel);
     c_variables->setRootIsDecorated(false);
     c_variables->header()->setStretchLastSection(true);
     c_variables->setSelectionBehavior(QAbstractItemView::SelectRows);
     c_variables->setSelectionMode(QAbstractItemView::SingleSelection);
-    
+
     c_exp = new Analitza::ExpressionEdit(console);
     c_exp->setAnalitza(c_results->analitza());
     c_exp->setExamples(QStringList() << QStringLiteral("square:=x->x**2") << QStringLiteral("fib:=n->piecewise { eq(n,0)?0, eq(n,1)?1, ?fib(n-1)+fib(n-2) }"));
     c_dock_vars->setWidget(c_variables);
-    
+
     m_tabs->addTab(console, i18n("&Calculator"));
     console->setLayout(c_layo);
     c_layo->addWidget(c_results);
     c_layo->addWidget(c_exp);
-    
+
     connect(c_exp, &Analitza::ExpressionEdit::returnPressed, this, &KAlgebra::operate);
     connect(c_results, &ConsoleHtml::status, this, &KAlgebra::changeStatusBar);
     connect(c_results, &ConsoleHtml::changed, this, &KAlgebra::updateInformation);
@@ -168,41 +192,28 @@ KAlgebra::KAlgebra(QWidget *parent)
     connect(c_variables, &QAbstractItemView::clicked, this, &KAlgebra::edit_var);
     ////////menu
     c_menu = menuBar()->addMenu(i18n("C&alculator"));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-open")), i18nc("@item:inmenu", "&Load Script..."),
-                        this, SLOT(loadScript()), Qt::CTRL | Qt::Key_L);
-#else
-    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-open")), i18nc("@item:inmenu", "&Load Script..."), Qt::CTRL | Qt::Key_L,
-                        this, SLOT(loadScript()));
-#endif
-    c_recentScripts=new KRecentFilesAction(QIcon::fromTheme(QStringLiteral("document-open-recent")), i18n("Recent Scripts"), this);
+    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-open")),
+                      i18nc("@item:inmenu", "&Load Script..."),
+                      Qt::CTRL | Qt::Key_L,
+                      this,
+                      SLOT(loadScript()));
+    c_recentScripts = new KRecentFilesAction(QIcon::fromTheme(QStringLiteral("document-open-recent")), i18n("Recent Scripts"), this);
     connect(c_recentScripts, SIGNAL(urlSelected(QUrl)), this, SLOT(loadScript(QUrl)));
     c_menu->addAction(c_recentScripts);
-    
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Save Script..."),
-                        this, &KAlgebra::saveScript, Qt::CTRL | Qt::Key_G);
-    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Export Log..."),
-                        this, &KAlgebra::saveLog, QKeySequence::Save);
-#else
-    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Save Script..."), Qt::CTRL | Qt::Key_G,
-                        this, &KAlgebra::saveScript);
-    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Export Log..."), QKeySequence::Save,
-                        this, &KAlgebra::saveLog);
-#endif
+
+    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")),
+                      i18nc("@item:inmenu", "&Save Script..."),
+                      Qt::CTRL | Qt::Key_G,
+                      this,
+                      &KAlgebra::saveScript);
+    c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Export Log..."), QKeySequence::Save, this, &KAlgebra::saveLog);
     c_menu->addSeparator();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    c_menu->addAction(i18nc("@item:inmenu", "&Insert ans..."),
-                        this, &KAlgebra::insertAns, Qt::Key_F3);
-#else
-    c_menu->addAction(i18nc("@item:inmenu", "&Insert ans..."),
-                        Qt::Key_F3, this, &KAlgebra::insertAns);
-#endif
+    c_menu->addAction(i18nc("@item:inmenu", "&Insert ans..."), Qt::Key_F3, this, &KAlgebra::insertAns);
     c_menu->addSeparator()->setText(i18n("Execution Mode"));
     QActionGroup *execGroup = new QActionGroup(c_menu);
-    QAction* calc = c_menu->addAction(i18nc("@item:inmenu", "Calculate"), this, &KAlgebra::consoleCalculate);
-    QAction* eval = c_menu->addAction(i18nc("@item:inmenu", "Evaluate"), this, &KAlgebra::consoleEvaluate);
-    
+    QAction *calc = c_menu->addAction(i18nc("@item:inmenu", "Calculate"), this, &KAlgebra::consoleCalculate);
+    QAction *eval = c_menu->addAction(i18nc("@item:inmenu", "Evaluate"), this, &KAlgebra::consoleEvaluate);
+
     calc->setCheckable(true);
     eval->setCheckable(true);
     eval->setChecked(true);
@@ -213,55 +224,55 @@ KAlgebra::KAlgebra(QWidget *parent)
     initializeRecentScripts();
     ////////////
     //////EOConsola
-    
+
     //////2D Graph
-    b_funcsModel=new Analitza::PlotsModel(this);
-    
+    b_funcsModel = new Analitza::PlotsModel(this);
+
     m_graph2d = new Analitza::PlotsView2D(m_tabs);
     m_graph2d->setTicksShown(Qt::Orientation(0));
     m_graph2d->setModel(b_funcsModel);
-    
+
     b_dock_funcs = new QDockWidget(i18n("Functions"), this);
     b_tools = new QTabWidget(b_dock_funcs);
     b_tools->setTabPosition(QTabWidget::South);
     addDockWidget(Qt::RightDockWidgetArea, b_dock_funcs);
-    
+
     b_funcs = new QTreeView(b_tools);
     b_funcs->setRootIsDecorated(false);
     b_funcs->setModel(b_funcsModel);
     b_funcs->header()->resizeSections(QHeaderView::ResizeToContents);
     b_funcs->setSelectionMode(QAbstractItemView::SingleSelection);
     m_graph2d->setSelectionModel(b_funcs->selectionModel());
-    
+
     b_tools->addTab(b_funcs, i18n("List"));
-    
+
     b_funced = new FunctionEdit(b_tools);
     b_funced->setVariables(c_varsModel->variables());
     connect(b_funced, &FunctionEdit::accept, this, &KAlgebra::new_func);
     connect(b_funced, &FunctionEdit::removeEditingPlot, this, &KAlgebra::remove_func);
     b_tools->addTab(b_funced, QIcon::fromTheme(QStringLiteral("list-add")), i18n("&Add"));
-    
-    QTableView* b_varsView=new QTableView(b_tools);
-    b_varsModel=new Analitza::VariablesModel(b_funced->variables());
+
+    QTableView *b_varsView = new QTableView(b_tools);
+    b_varsModel = new Analitza::VariablesModel(b_funced->variables());
     b_varsView->setModel(b_varsModel);
     b_varsView->setShowGrid(false);
     b_varsView->verticalHeader()->hide();
     b_varsView->horizontalHeader()->setStretchLastSection(true);
     b_varsView->setSelectionBehavior(QAbstractItemView::SelectRows);
     b_varsView->setContextMenuPolicy(Qt::CustomContextMenu);
-    VariablesDelegate* delegate=new VariablesDelegate(b_varsView);
+    VariablesDelegate *delegate = new VariablesDelegate(b_varsView);
     b_varsView->setItemDelegate(delegate);
     b_tools->addTab(b_varsView, i18n("Variables"));
-    
-    ViewportWidget* b_viewport = new ViewportWidget(this);
+
+    ViewportWidget *b_viewport = new ViewportWidget(this);
     b_viewport->setViewport(m_graph2d->definedViewport());
     b_tools->addTab(b_viewport, i18n("Viewport"));
-    
+
     b_dock_funcs->setWidget(b_tools);
     b_dock_funcs->setFeatures(QDockWidget::DockWidgetFloatable | QDockWidget::DockWidgetMovable);
     m_tabs->addTab(m_graph2d, i18n("&2D Graph"));
     c_results->addOptionsObserver(new Add2DOption(this));
-    
+
     connect(b_varsModel, &QAbstractItemModel::dataChanged, this, &KAlgebra::valueChanged);
     connect(b_funcs, &QAbstractItemView::doubleClicked, this, &KAlgebra::edit_func);
     connect(b_tools, &QTabWidget::currentChanged, this, &KAlgebra::functools);
@@ -269,17 +280,17 @@ KAlgebra::KAlgebra(QWidget *parent)
     connect(m_graph2d, SIGNAL(viewportChanged(QRectF)), b_viewport, SLOT(setViewport(QRectF)));
     connect(b_viewport, SIGNAL(viewportChange(QRectF)), m_graph2d, SLOT(changeViewport(QRectF)));
     connect(b_varsView, &QWidget::customContextMenuRequested, this, &KAlgebra::varsContextMenu);
-    
+
     ////////menu
     b_menu = menuBar()->addMenu(i18n("2&D Graph"));
-    QAction* b_actions[6];
+    QAction *b_actions[6];
     b_actions[0] = b_menu->addAction(i18n("&Grid"), this, &KAlgebra::toggleSquares);
     b_actions[1] = b_menu->addAction(i18n("&Keep Aspect Ratio"), this, &KAlgebra::toggleKeepAspect);
     b_menu->addAction(KStandardAction::save(this, SLOT(saveGraph()), this));
     b_menu->addSeparator();
     b_menu->addAction(KStandardAction::zoomIn(m_graph2d, SLOT(zoomIn()), this));
     b_menu->addAction(KStandardAction::zoomOut(m_graph2d, SLOT(zoomOut()), this));
-    QAction* ac=KStandardAction::actualSize(m_graph2d, SLOT(resetViewport()), this);
+    QAction *ac = KStandardAction::actualSize(m_graph2d, SLOT(resetViewport()), this);
     ac->setShortcut({Qt::ControlModifier | Qt::Key_0});
     b_menu->addAction(ac);
     b_menu->addSeparator()->setText(i18n("Resolution"));
@@ -289,13 +300,13 @@ KAlgebra::KAlgebra(QWidget *parent)
     b_actions[5] = b_menu->addAction(i18nc("@item:inmenu", "Very Fine"), this, &KAlgebra::set_res_vfine);
     m_graph2d->setContextMenuPolicy(Qt::ActionsContextMenu);
     m_graph2d->addActions(b_menu->actions());
-    
+
     QActionGroup *res = new QActionGroup(b_menu);
     res->addAction(b_actions[2]);
     res->addAction(b_actions[3]);
     res->addAction(b_actions[4]);
     res->addAction(b_actions[5]);
-    
+
     b_actions[0]->setCheckable(true);
     b_actions[0]->setChecked(true);
     b_actions[1]->setCheckable(true);
@@ -307,7 +318,7 @@ KAlgebra::KAlgebra(QWidget *parent)
     b_actions[5]->setCheckable(true);
     set_res_std();
     //////EO2D Graph
-    
+
     /////3DGraph
     QWidget *tridim = new QWidget(m_tabs);
     QVBoxLayout *t_layo = new QVBoxLayout(tridim);
@@ -318,30 +329,32 @@ KAlgebra::KAlgebra(QWidget *parent)
     m_graph3d = new Analitza::PlotsView3DES(tridim);
     m_graph3d->setModel(t_model3d);
     m_graph3d->setUseSimpleRotation(true);
-    
+
     tridim->setLayout(t_layo);
     m_tabs->addTab(tridim, i18n("&3D Graph"));
     t_layo->addWidget(m_graph3d);
     t_layo->addWidget(t_exp);
-    
-    connect(t_exp,  &Analitza::ExpressionEdit::returnPressed, this, &KAlgebra::new_func3d);
+
+    connect(t_exp, &Analitza::ExpressionEdit::returnPressed, this, &KAlgebra::new_func3d);
     c_results->addOptionsObserver(new Add3DOption(this));
-    
+
     ////////menu
     t_menu = menuBar()->addMenu(i18n("3D &Graph"));
-    QAction* t_actions[5];
+    QAction *t_actions[5];
     t_menu->addAction(KStandardAction::save(this, SLOT(save3DGraph()), this));
-    t_menu->addAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("&Reset View"), m_graph3d, [this]() { m_graph3d->resetViewport(); });
+    t_menu->addAction(QIcon::fromTheme(QStringLiteral("zoom-original")), i18n("&Reset View"), m_graph3d, [this]() {
+        m_graph3d->resetViewport();
+    });
     t_menu->addSeparator();
     t_actions[2] = t_menu->addAction(i18n("Dots"), this, &KAlgebra::set_dots);
     t_actions[3] = t_menu->addAction(i18n("Lines"), this, &KAlgebra::set_lines);
     t_actions[4] = t_menu->addAction(i18n("Solid"), this, &KAlgebra::set_solid);
-    
+
     QActionGroup *t_type = new QActionGroup(t_menu);
     t_type->addAction(t_actions[2]);
     t_type->addAction(t_actions[3]);
     t_type->addAction(t_actions[4]);
-    
+
     t_actions[2]->setCheckable(true);
     t_actions[3]->setCheckable(true);
     t_actions[4]->setCheckable(true);
@@ -350,17 +363,17 @@ KAlgebra::KAlgebra(QWidget *parent)
     ////////////
     //////EO3D Graph
     menuBar()->addAction(QStringLiteral("|"))->setEnabled(false);
-    
-    //Dictionary tab
+
+    // Dictionary tab
     d_dock = new QDockWidget(i18n("Operations"), this);
     d_dock->setFeatures(QDockWidget::DockWidgetFloatable | QDockWidget::DockWidgetMovable);
     addDockWidget(Qt::RightDockWidgetArea, d_dock);
     Dictionary *dic = new Dictionary(m_tabs);
     m_tabs->addTab(dic, i18n("&Dictionary"));
-    
-    QWidget *w=new QWidget;
-    QLayout *leftLayo=new QVBoxLayout(w);
-    d_filter=new QLineEdit(w);
+
+    QWidget *w = new QWidget;
+    QLayout *leftLayo = new QVBoxLayout(w);
+    d_filter = new QLineEdit(w);
     d_filter->setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
     connect(d_filter, &QLineEdit::textChanged, dic, &Dictionary::setFilter);
     connect(d_filter, &QLineEdit::textChanged, this, &KAlgebra::dictionaryFilterChanged);
@@ -371,21 +384,20 @@ KAlgebra::KAlgebra(QWidget *parent)
     leftLayo->addWidget(d_filter);
     leftLayo->addWidget(d_list);
     d_dock->setWidget(w);
-    
-    connect(d_list->selectionModel(), &QItemSelectionModel::currentChanged,
-        dic, &Dictionary::activated);
-    
-    //EODictionary
-    //Ego's reminder
-    KHelpMenu* help = new KHelpMenu(this);
+
+    connect(d_list->selectionModel(), &QItemSelectionModel::currentChanged, dic, &Dictionary::activated);
+
+    // EODictionary
+    // Ego's reminder
+    KHelpMenu *help = new KHelpMenu(this);
     menuBar()->addMenu(help->menu());
 
 #pragma message("TODO: Port to PlotsModel")
-//     connect(b_funcsModel, SIGNAL(functionModified(QString,Analitza::Expression)),
-//             c_results, SLOT(modifyVariable(QString,Analitza::Expression)));
-//     connect(b_funcsModel, SIGNAL(functionRemoved(QString)),
-//             c_results, SLOT(removeVariable(QString)));
-    
+    //     connect(b_funcsModel, SIGNAL(functionModified(QString,Analitza::Expression)),
+    //             c_results, SLOT(modifyVariable(QString,Analitza::Expression)));
+    //     connect(b_funcsModel, SIGNAL(functionRemoved(QString)),
+    //             c_results, SLOT(removeVariable(QString)));
+
     connect(m_tabs, &QTabWidget::currentChanged, this, &KAlgebra::tabChanged);
     tabChanged(0);
 }
@@ -395,9 +407,10 @@ KAlgebra::~KAlgebra()
     KConfig conf(QStringLiteral("kalgebrarc"));
     KConfigGroup config(&conf, "Default");
     QStringList urls;
-    foreach(const QUrl& url, c_recentScripts->urls())
+    const auto recentScripts = c_recentScripts->urls();
+    for (const QUrl &url : recentScripts)
         urls += url.toDisplayString();
-    
+
     config.writeEntry("recent", urls);
 }
 
@@ -405,9 +418,9 @@ void KAlgebra::initializeRecentScripts()
 {
     KConfig conf(QStringLiteral("kalgebrarc"));
     KConfigGroup config(&conf, "Default");
-    
-    QStringList urls=config.readEntry("recent", QStringList());
-    foreach(const QString& url, urls) {
+
+    const QStringList urls = config.readEntry("recent", QStringList());
+    for (const QString &url : urls) {
         c_recentScripts->addUrl(QUrl(url));
     }
 }
@@ -417,28 +430,28 @@ void KAlgebra::newInstance()
     QProcess::startDetached(QApplication::applicationFilePath(), QStringList());
 }
 
-void KAlgebra::add2D(const Analitza::Expression& exp)
+void KAlgebra::add2D(const Analitza::Expression &exp)
 {
     qDebug() << "adding" << exp.toString();
-    
+
     Analitza::PlotBuilder req = Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim2D, c_results->analitza()->variables());
-    Analitza::PlotItem* curve = req.create(randomFunctionColor(), b_funcsModel->freeId());
+    Analitza::PlotItem *curve = req.create(randomFunctionColor(), b_funcsModel->freeId());
     b_funcsModel->addPlot(curve);
-    
+
     m_tabs->setCurrentIndex(1);
 }
 
 void KAlgebra::new_func()
 {
-    Analitza::FunctionGraph* f=b_funced->createFunction();
-    
-    if(b_funced->editing()) {
+    Analitza::FunctionGraph *f = b_funced->createFunction();
+
+    if (b_funced->editing()) {
         QModelIndex idx = b_funcsModel->indexForName(f->name());
         b_funcsModel->updatePlot(idx.row(), f);
     } else {
         b_funcsModel->addPlot(f);
     }
-    
+
     b_funced->setEditing(false);
     b_funced->clear();
     b_tools->setCurrentIndex(0);
@@ -450,7 +463,7 @@ void KAlgebra::remove_func()
 {
     Q_ASSERT(b_funced->editing());
     b_funcsModel->removeRow(b_funcs->currentIndex().row());
-    
+
     b_funced->setEditing(false);
     b_funced->clear();
     b_tools->setCurrentIndex(0);
@@ -470,7 +483,7 @@ void KAlgebra::edit_func(const QModelIndex &idx)
 
 void KAlgebra::functools(int i)
 {
-    if(i==0)
+    if (i == 0)
         b_tools->setTabText(1, i18n("&Add"));
     else {
         b_funced->setName(b_funcsModel->freeId());
@@ -482,19 +495,19 @@ void KAlgebra::functools(int i)
 
 void KAlgebra::edit_var(const QModelIndex &idx)
 {
-    if(idx.column()==0) {
+    if (idx.column() == 0) {
         c_exp->insertText(idx.data().toString());
     } else {
-        QModelIndex idxName=idx.sibling(idx.row(), 0);
-        
+        QModelIndex idxName = idx.sibling(idx.row(), 0);
+
         QPointer<VarEdit> e(new VarEdit(this, false));
         QString var = c_variables->model()->data(idxName, Qt::DisplayRole).toString();
-        
+
         e->setAnalitza(c_results->analitza());
         e->setName(var);
-        
-        if(e->exec() == QDialog::Accepted) {
-            QString str=var+" := "+e->val().toString();
+
+        if (e->exec() == QDialog::Accepted) {
+            QString str = var + u" := "_s + e->val().toString();
             c_results->addOperation(Analitza::Expression(str, false), str);
         }
         delete e;
@@ -503,49 +516,49 @@ void KAlgebra::edit_var(const QModelIndex &idx)
 
 void KAlgebra::operate()
 {
-    if(!c_exp->text().isEmpty()){
+    if (!c_exp->text().isEmpty()) {
         c_exp->setCorrect(c_results->addOperation(c_exp->expression(), c_exp->toPlainText()));
         c_exp->selectAll();
     }
 }
 
-void KAlgebra::changeStatusBar(const QString& msg)
+void KAlgebra::changeStatusBar(const QString &msg)
 {
-//     statusBar()->showMessage(msg);
+    //     statusBar()->showMessage(msg);
     m_status->setText(msg);
 }
 
 void KAlgebra::loadScript()
 {
     QUrl path = QFileDialog::getOpenFileUrl(this, i18n("Choose a script"), QUrl(), i18n("Script (*.kal)"));
-    
-    if(!path.isEmpty())
+
+    if (!path.isEmpty())
         loadScript(path);
 }
 
-void KAlgebra::loadScript(const QUrl& path)
+void KAlgebra::loadScript(const QUrl &path)
 {
-    bool loaded=c_results->loadScript(path);
-    
-    if(loaded)
+    bool loaded = c_results->loadScript(path);
+
+    if (loaded)
         c_recentScripts->addUrl(path);
 }
 
 void KAlgebra::saveScript()
 {
     QUrl path = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), i18n("Script (*.kal)"));
-    bool loaded=false;
-    if(!path.isEmpty())
-        loaded=c_results->saveScript(path);
-    
-    if(loaded)
+    bool loaded = false;
+    if (!path.isEmpty())
+        loaded = c_results->saveScript(path);
+
+    if (loaded)
         c_recentScripts->addUrl(path);
 }
 
 void KAlgebra::saveLog()
 {
     QUrl path = QFileDialog::getSaveFileUrl(this, QString(), QUrl(), i18n("HTML File (*.html)"));
-    if(!path.isEmpty())
+    if (!path.isEmpty())
         c_results->saveLog(path);
 }
 
@@ -554,16 +567,28 @@ void KAlgebra::insertAns()
     c_exp->insertText(QStringLiteral("ans"));
 }
 
-void KAlgebra::set_res_low()    { b_funcsModel->setResolution(416); }
-void KAlgebra::set_res_std()    { b_funcsModel->setResolution(832); }
-void KAlgebra::set_res_fine()    { b_funcsModel->setResolution(1664);}
-void KAlgebra::set_res_vfine()    { b_funcsModel->setResolution(3328);}
+void KAlgebra::set_res_low()
+{
+    b_funcsModel->setResolution(416);
+}
+void KAlgebra::set_res_std()
+{
+    b_funcsModel->setResolution(832);
+}
+void KAlgebra::set_res_fine()
+{
+    b_funcsModel->setResolution(1664);
+}
+void KAlgebra::set_res_vfine()
+{
+    b_funcsModel->setResolution(3328);
+}
 
 void KAlgebra::new_func3d()
 {
     Analitza::Expression exp = t_exp->expression();
     Analitza::PlotBuilder plot = Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D, c_results->analitza()->variables());
-    if(plot.canDraw()) {
+    if (plot.canDraw()) {
         t_model3d->clear();
         t_model3d->addPlot(plot.create(Qt::yellow, QStringLiteral("func3d")));
     } else
@@ -588,14 +613,14 @@ void KAlgebra::set_solid()
 void KAlgebra::save3DGraph()
 {
     QString path = QFileDialog::getSaveFileName(this, QString(), QString(), m_graph3d->filters().join(QStringLiteral(";;")));
-    if(!path.isEmpty()) {
+    if (!path.isEmpty()) {
         m_graph3d->save(QUrl::fromLocalFile(path));
     }
 }
 
 void KAlgebra::toggleSquares()
 {
-    m_graph2d->setTicksShown(m_graph2d->ticksShown() ? (Qt::Horizontal|Qt::Vertical) : ~(Qt::Horizontal|Qt::Vertical));
+    m_graph2d->setTicksShown(m_graph2d->ticksShown() ? (Qt::Horizontal | Qt::Vertical) : ~(Qt::Horizontal | Qt::Vertical));
 }
 
 void KAlgebra::toggleKeepAspect()
@@ -605,23 +630,25 @@ void KAlgebra::toggleKeepAspect()
 
 void KAlgebra::saveGraph()
 {
-    QPointer<QFileDialog> dialog=new QFileDialog(this, i18n("Select where to put the rendered plot"), QString(), i18n("Image File (*.png);;SVG File (*.svg)"));
+    QPointer<QFileDialog> dialog =
+        new QFileDialog(this, i18n("Select where to put the rendered plot"), QString(), i18n("Image File (*.png);;SVG File (*.svg)"));
     dialog->setOption(QFileDialog::DontConfirmOverwrite, false);
-    if(dialog->exec() && !dialog->selectedFiles().isEmpty()) {
+    if (dialog->exec() && !dialog->selectedFiles().isEmpty()) {
         QString filter = dialog->selectedNameFilter();
         QString filename = dialog->selectedFiles().first();
-        
-        bool isSvg = filename.endsWith(QLatin1String(".svg")) || (!filename.endsWith(QLatin1String(".png")) && filter.mid(2, 3)==QLatin1String("svg"));
+
+        bool isSvg = filename.endsWith(QLatin1String(".svg")) || (!filename.endsWith(QLatin1String(".png")) && filter.mid(2, 3) == QLatin1String("svg"));
         Analitza::PlotsView2D::Format f = isSvg ? Analitza::PlotsView2D::SVG : Analitza::PlotsView2D::PNG;
         m_graph2d->toImage(filename, f);
     }
     delete dialog;
 }
 
-void menuEnabledHelper(QMenu* m, bool enabled)
+void menuEnabledHelper(QMenu *m, bool enabled)
 {
     m->setEnabled(enabled);
-    foreach(QAction* action, m->actions()) {
+    const auto actions = m->actions();
+    for (QAction *action : actions) {
         action->setEnabled(enabled);
     }
 }
@@ -631,41 +658,41 @@ void KAlgebra::tabChanged(int n)
     c_dock_vars->hide();
     b_dock_funcs->hide();
     d_dock->hide();
-    
-    menuEnabledHelper(c_menu, n==0);
-    menuEnabledHelper(b_menu, n==1);
-    menuEnabledHelper(t_menu, n==2);
+
+    menuEnabledHelper(c_menu, n == 0);
+    menuEnabledHelper(b_menu, n == 1);
+    menuEnabledHelper(t_menu, n == 2);
 
     m_status->clear();
-    
-    switch(n) {
-        case 0:
-            c_dock_vars->show();
-            c_dock_vars->raise();
-            c_exp->setFocus();
-            break;
-        case 1:
-            b_dock_funcs->show();
-            b_dock_funcs->raise();
-            
-            if(b_funcsModel->rowCount()==0)
-                b_tools->setCurrentIndex(1); //We set the Add tab
-//             b_add->setFocus();
-            break;
-        case 2:
-            t_exp->setFocus();
-            break;
-        case 3:
-            d_filter->setFocus();
-            d_dock->show();
-            d_dock->raise();
-        default:
-            break;
+
+    switch (n) {
+    case 0:
+        c_dock_vars->show();
+        c_dock_vars->raise();
+        c_exp->setFocus();
+        break;
+    case 1:
+        b_dock_funcs->show();
+        b_dock_funcs->raise();
+
+        if (b_funcsModel->rowCount() == 0)
+            b_tools->setCurrentIndex(1); // We set the Add tab
+        //             b_add->setFocus();
+        break;
+    case 2:
+        t_exp->setFocus();
+        break;
+    case 3:
+        d_filter->setFocus();
+        d_dock->show();
+        d_dock->raise();
+    default:
+        break;
     }
     changeStatusBar(i18nc("@info:status", "Ready"));
 }
 
-void KAlgebra::select(const QModelIndex & idx)
+void KAlgebra::select(const QModelIndex &idx)
 {
     b_funcs->selectionModel()->setCurrentIndex(idx, QItemSelectionModel::ClearAndSelect);
 }
@@ -688,28 +715,28 @@ void KAlgebra::consoleEvaluate()
 
 void KAlgebra::valueChanged()
 {
-    //FIXME: Should only repaint the affected ones.
-    if(b_funcsModel->rowCount()>0)
-        m_graph2d->updateFunctions(QModelIndex(), 0, b_funcsModel->rowCount()-1);
+    // FIXME: Should only repaint the affected ones.
+    if (b_funcsModel->rowCount() > 0)
+        m_graph2d->updateFunctions(QModelIndex(), 0, b_funcsModel->rowCount() - 1);
 }
 
-void KAlgebra::varsContextMenu(const QPoint& p)
+void KAlgebra::varsContextMenu(const QPoint &p)
 {
-    QPointer<QMenu> m=new QMenu;
+    QPointer<QMenu> m = new QMenu;
     m->addAction(i18n("Add variable"));
-    QAction* ac=m->exec(b_dock_funcs->widget()->mapToGlobal(p));
-    
-    if(ac) {
-        QPointer<AskName> a=new AskName(i18n("Enter a name for the new variable"), 0);
-        
-        if(a->exec()==QDialog::Accepted)
+    QAction *ac = m->exec(b_dock_funcs->widget()->mapToGlobal(p));
+
+    if (ac) {
+        QPointer<AskName> a = new AskName(i18n("Enter a name for the new variable"), nullptr);
+
+        if (a->exec() == QDialog::Accepted)
             b_varsModel->insertVariable(a->name(), Analitza::Expression(Analitza::Cn(0)));
         delete a;
     }
     delete m;
 }
 
-void KAlgebra::add3D(const Analitza::Expression& exp)
+void KAlgebra::add3D(const Analitza::Expression &exp)
 {
     t_model3d->clear();
     Analitza::PlotBuilder plot = Analitza::PlotsFactory::self()->requestPlot(exp, Analitza::Dim3D, c_results->analitza()->variables());
@@ -718,20 +745,20 @@ void KAlgebra::add3D(const Analitza::Expression& exp)
     m_tabs->setCurrentIndex(2);
 }
 
-void KAlgebra::dictionaryFilterChanged(const QString&)
+void KAlgebra::dictionaryFilterChanged(const QString &)
 {
-    if(d_list->model()->rowCount()==1)
-        d_list->setCurrentIndex(d_list->model()->index(0,0));
+    if (d_list->model()->rowCount() == 1)
+        d_list->setCurrentIndex(d_list->model()->index(0, 0));
 }
 
 void KAlgebra::fullScreen(bool isFull)
 {
     m_tabs->setDocumentMode(isFull);
     m_tabs->setTabEnabled(3, !isFull);
-    if(isFull) {
+    if (isFull) {
         hide();
-        m_tabs->setParent(0);
-        setCentralWidget(0);
+        m_tabs->setParent(nullptr);
+        setCentralWidget(nullptr);
         m_tabs->showFullScreen();
     } else {
         setCentralWidget(m_tabs);
